@@ -42,7 +42,7 @@ class KNativeKafkaConsumer(threading.Thread):
         is_tls_enable=os.getenv('KAFKA_NET_TLS_ENABLE',default='False')
         self.logger.info(is_tls_enable)
         print(is_tls_enable)
-        if is_tls_enable == 'True':
+        if is_tls_enable == 'True' or is_tls_enable == 'true':
             self.security_protocol="SSL"
             if 'KAFKA_NET_TLS_CA_CERT' not in os.environ:
                 raise ValueError( 'TLS CA Certificate is required!')
@@ -61,6 +61,7 @@ class KNativeKafkaConsumer(threading.Thread):
             self.ssl_certfile=None
             self.ssl_keyfile=None
         self.logger.info("KafkaConsumer Instance Creation")
+        print("KafkaConsumer Instance Creation")
         try:                
 
             self.consumer=KafkaConsumer(
